Struct amazon_sp_fulfillment_inbound::models::box_contents_fee_details::BoxContentsFeeDetails
source · [−]pub struct BoxContentsFeeDetails {
pub total_units: Option<i32>,
pub fee_per_unit: Option<Box<Amount>>,
pub total_fee: Option<Box<Amount>>,
}Expand description
BoxContentsFeeDetails : The manual processing fee per unit and total fee for a shipment.
Fields
total_units: Option<i32>The item quantity.
fee_per_unit: Option<Box<Amount>>total_fee: Option<Box<Amount>>Implementations
sourceimpl BoxContentsFeeDetails
impl BoxContentsFeeDetails
sourcepub fn new() -> BoxContentsFeeDetails
pub fn new() -> BoxContentsFeeDetails
The manual processing fee per unit and total fee for a shipment.